@@ -121,6 +121,7 @@ gchar* anjuta_util_str_middle_truncate (const gchar *string,
 										 guint        truncate_length);
 
 gboolean anjuta_util_is_project_file (const gchar *filename);
+gboolean anjuta_util_is_template_file (const gchar *filename);
 gchar* anjuta_util_get_file_mime_type (GFile *file);
 gchar* anjuta_util_get_local_path_from_uri (const gchar *uri);
 
@@ -147,7 +148,7 @@ GtkBuilder *anjuta_util_builder_new (const gchar *filename, GError **error);
 gboolean anjuta_util_builder_get_objects (GtkBuilder *builder, const gchar *first_widget,...);
 
 /* Helper for drag and drop */
-GSList *anjuta_utils_drop_get_files (GtkSelectionData *selection_data);
+GSList *anjuta_util_drop_get_files (GtkSelectionData *selection_data);
 
 /* Temporarily copied here */
 
