@@ -1,6 +1,6 @@
 
 #include <libanjuta/anjuta-plugin.h>
-#include <libegg/recent-files/egg-recent-model.h>
+#include <gtk/gtk.h>
 
 extern GType anjuta_file_loader_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_FILE_LOADER         (anjuta_file_loader_plugin_get_type (NULL))
@@ -15,19 +15,22 @@ typedef struct _AnjutaFileLoaderPluginClass AnjutaFileLoaderPluginClass;
 
 struct _AnjutaFileLoaderPlugin{
 	AnjutaPlugin parent;
-	EggRecentModel *recent_files_model_top;
-	EggRecentModel *recent_files_model_bottom;
+	
+	GtkRecentManager *recent_manager;
 	GtkActionGroup *action_group;
 	GtkActionGroup *popup_action_group;
 	GtkActionGroup *recent_group;
 	
 	gchar *fm_current_uri;
 	gchar *pm_current_uri;
-	
+	gchar *dm_current_uri;
+  
 	gint fm_watch_id;
 	gint pm_watch_id;
+  	gint dm_watch_id;
 	
 	gint uiid;
+
 };
 
 struct _AnjutaFileLoaderPluginClass{
