@@ -222,7 +222,7 @@ giggle_graph_renderer_get_size (GtkCellRenderer *cell,
 	gint size;
 
 	priv = GIGGLE_GRAPH_RENDERER (cell)->_priv;
-	size = PANGO_PIXELS (pango_font_description_get_size (widget->style->font_desc));
+	size = PANGO_PIXELS (pango_font_description_get_size (gtk_widget_get_style (widget)->font_desc));
 
 	if (height) {
 		*height = PATH_SPACE (size);
@@ -273,7 +273,7 @@ giggle_graph_renderer_render (GtkCellRenderer *cell,
 	y = background_area->y;
 	h = background_area->height;
 	revision = priv->revision;
-	size = PANGO_PIXELS (pango_font_description_get_size (widget->style->font_desc));
+	size = PANGO_PIXELS (pango_font_description_get_size (gtk_widget_get_style (widget)->font_desc));
 
 	table = g_hash_table_new (g_direct_hash, g_direct_equal);
 	paths_state = g_object_get_qdata (G_OBJECT (revision), revision_paths_state_quark);
@@ -414,7 +414,7 @@ get_initial_status (GHashTable *visible_paths)
 static void
 free_paths_state (GArray *array)
 {
-	g_array_free (array, FALSE);
+	g_array_free (array, TRUE);
 }
 
 static void
