@@ -39,6 +39,7 @@
 
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-utils.h>
+#include <libanjuta/anjuta-pkg-config-chooser.h>
 
 /*---------------------------------------------------------------------------*/
 
@@ -80,7 +81,8 @@ static const gchar* NPWPropertyTypeString[] = {
 	"list",
 	"directory",
 	"file",
-	"icon"
+	"icon",
+	"package",
 };
 
 static const gchar* NPWPropertyRestrictionString[] = {
@@ -369,13 +371,11 @@ cb_browse_button_clicked (GtkButton *button, NPWProperty* prop)
 	}
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
-  	{
-    	gchar *filename;
-
-    	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-		gtk_entry_set_text (GTK_ENTRY (prop->widget), filename);
-    	g_free (filename);
-  	}
+	{
+		gchar* name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		gtk_entry_set_text (GTK_ENTRY (prop->widget), name);
+		g_free (name);
+	}
 	gtk_widget_destroy (dialog);
 }
 
@@ -554,6 +554,19 @@ npw_property_create_widget (NPWProperty* prop)
 		if (value) gtk_entry_set_text (GTK_ENTRY (child), value);
 		break;
 	}
+	case NPW_PACKAGE_PROPERTY:
+	{
+		GtkWidget *scroll_window;
+		scroll_window = gtk_scrolled_window_new (NULL, NULL);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll_window), GTK_SHADOW_IN);
+
+		entry = anjuta_pkg_config_chooser_new ();
+		anjuta_pkg_config_chooser_show_active_column (ANJUTA_PKG_CONFIG_CHOOSER (entry), TRUE);
+		gtk_container_add (GTK_CONTAINER (scroll_window), entry);
+
+		widget = scroll_window;
+		break;
+	}
 	default:
 		return NULL;
 	}
@@ -618,6 +631,9 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 {
 	gchar* alloc_value = NULL;
 	const gchar* value = NULL;
+	GList* packages;
+	GList* node;
+	GString* str_value;
 	gboolean ok;
 
 	switch (prop->type)
@@ -668,6 +684,24 @@ npw_property_set_value_from_widget (NPWProperty* prop, NPWValueTag tag)
 		}
 		break;
 	}
+	case NPW_PACKAGE_PROPERTY:
+		packages = 
+			anjuta_pkg_config_chooser_get_active_packages (ANJUTA_PKG_CONFIG_CHOOSER (prop->widget));
+		str_value = NULL;
+		for (node = packages; node != NULL; node = g_list_next (node))
+		{
+			if (str_value)
+			{
+				g_string_append_printf (str_value, " %s", (gchar*) node->data);
+			}
+			else
+				str_value = g_string_new (node->data);
+		}
+		value = str_value->str;
+		g_string_free (str_value, FALSE);
+		g_list_foreach (packages, (GFunc) g_free, NULL);
+		g_list_free (packages);	
+		break;
 	default:
 		/* Hidden property */
 		value = prop->defvalue;
