@@ -5,9 +5,9 @@
 # Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
 # 
 [+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  "main.py" (get "Author") "# ")+]
-[+ == "LGPL" +][+(lgpl "main.py" (get "Author") "# ")+]
-[+ == "GPL"  +][+(gpl  "main.py"                "# ")+]
+[+ == "BSD"  +][+(bsd  (get "Name") (get "Author") "# ")+]
+[+ == "LGPL" +][+(lgpl (get "Name") (get "Author") "# ")+]
+[+ == "GPL"  +][+(gpl  (get "Name")                "# ")+]
 [+ESAC+]
 
 print "Hello World!"
